杀人回忆 (豆瓣)
Description: 杀人回忆电影简介和剧情介绍,杀人回忆影评、图片、预告片、影讯、论坛、在线购票
Keywords: 杀人回忆,살인의 추억,杀人回忆影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.94豆瓣电影Top250

# 杀人回忆 살인의 추억 (2003)

导演: 奉俊昊
编剧: 奉俊昊 / 沈成宝 / 金光林
主演: 宋康昊 / 金相庆 / 金雷夏 / 宋在浩 / 边希峰 / 高瑞熙 / 柳泰浩 / 朴努植 / 朴海日 / 全美善 / 徐永嬅 / 崔钟律 / 刘承睦 / 申贤宗 / 李在应 / 郑仁仙 / 吴龙 / 朴真宇 / 朴泰京 / 沈成宝
类型: 剧情 / 动作 / 悬疑 / 惊悚 / 犯罪
制片国家/地区: 韩国
语言: 韩语 / 英语
上映日期: 2003-05-02(韩国)
片长: 132分钟
又名: 谋杀回忆 / 杀手回忆录 / Salinui chueok / Memories of Murder
IMDb: tt0353969
豆瓣评分
引用
8.9
669865人评价
5星
54.0%
4星
37.7%
3星
7.6%
2星
0.6%
1星
0.2%
好于 98% 悬疑片
好于 98% 犯罪片
想看 看过
评价:
推荐

## 杀人回忆的剧情简介 · · · · · ·

1986年，韩国京畿道华城郡，热得发昏的夏天，在田野边发现一具女尸，早已发臭。小镇警察朴探员（宋康昊饰）和汉城来的苏探员（金相庆饰）接手案件，唯一可证实的是这具女尸生前被强奸过。线索的严重缺乏让毫无经验的朴探员和搭档曹探员（金罗河饰）只凭粗暴逼供和第六感推断，几次将犯罪 嫌疑人屈打成招。而苏探员客观冷静，据理分析，几次排除嫌疑，警察内部为了证明与推翻矛盾不断，然而无辜女子还是接二连三被残忍杀害，他们只好达成共识一起合作。此时，一个极其符合作案特征的小青年（朴海日饰）成为最大嫌疑人，警方神经绷紧地锁定住他，同时DNA检测报告也被送往美国，然而案件并未在此处停止。 ©豆瓣

## 杀人回忆的演职员 · · · · · · ( 全部 62 )

- 奉俊昊 导演
- 宋康昊 饰 朴探员
- 金相庆 演员
- 金雷夏 演员
- 宋在浩 演员
- 边希峰 演员

## 杀人回忆的视频和图片 · · · · · · ( 预告片2 | 视频评论1 · 添加 | 图片1172 · 添加 )

## 杀人回忆的获奖情况 · · · · · · ( 全部 )

- 第16届东京国际电影节
- 亚洲之风 最佳亚洲电影
- 奉俊昊

- 第51届圣塞巴斯蒂安国际电影节
- 金贝壳奖(提名)
- 奉俊昊

- 第51届圣塞巴斯蒂安国际电影节
- 最佳导演银贝壳奖
- 奉俊昊

## 喜欢这部电影的人也喜欢 · · · · · ·

  看不见的客人

  恐怖直播

  记忆碎片

  七宗罪

  禁闭岛

  控方证人

  致命ID

  猫鼠游戏

  沉默的羔羊

  追击者

我要写短评

## 杀人回忆的短评 · · · · · · ( 全部 138443 条 )

热门 / 最新 / 好友

### 7953 有用 狮子人 看过 2011-02-01 20:31:59

嗨凶手，你也在看这部片吗？送给你的，杀人回忆

### 7708 有用 南笙 看过 2012-06-30 00:33:11

想到真凶可能会若无其事坐在电影院里面，与电影最后一个镜头里宋康昊含泪的双眼四目相对就觉得好惊悚

### 6487 有用 桃桃林林 看过 2007-05-05 14:18:32

这并非一个寻求真相的故事，而是关于真到底相如何被整没了……

### 3833 有用 亵渎电影 看过 2011-08-14 20:54:50

真实事件玩了全世界，电影玩了你，总觉得离真相很近了，而真相却是没有真相。★★★★★

### 2507 有用 伍德与夏洛蒂 看过 2011-05-24 18:33:20

这片给我的阴影才是史无前例好么？5年前大学拉片课上看的，看完了已经半夜12点，我走回寝室腿都抖的站不起来，一年中再也没吃过桃子。奉俊昊和宋康昊联手，真不是闹着玩的，经典至极。

> 更多短评 138443条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 杀人回忆的影评 · · · · · · ( 全部 1630 条 )

热门 / 最新 / 好友
hannah(憨憨) 2007-06-10 21:40:36

## 你知道我那年雨夜干了什么？

这篇影评可能有剧透

网上的对此片的高度评论到了夸张的地步，摘录几位电影界人士的观后感： “史上最好看的韩国电影” “毫无破绽的完美电影” “这样的影片，放眼中国，无一导演有实力拍出。” “看过这个片子，中国电影真的可以回家休息了。” “在一流的商业技法中又能加载沉痛的集体反思，这也... (展开)
10184 499 778回应 收起
看客inSight 2019-09-26 11:45:03

## 我们翻遍韩网，复原了《杀人回忆》的真实情节

这篇影评可能有剧透

时隔33年，《杀人回忆》里的凶手原型找到了。 你肯定记得电影结尾那一幕：宋康昊饰演的刑警多年后重回案发现场，在迷茫与不甘中直视镜头——与真正的凶手对视。 这个让电影与现实发生交叠的眼神，把无数观众惊得起了一身鸡皮疙瘩。 而《杀人回忆》的案件原型 —— “华城连环杀... (展开)
4762 11 326回应 收起
木卫二 2006-03-29 21:29:31

## 阳光满溢的那天

1. 当初只看影片名字和内容简介就归为烧杀抢掠的类型片，下完没时间观看便Delete掉。想来实在太对不起这部电影。 《杀人回忆》，《看电影》杂志列出的100部最好韩国电影排名第一。对于类似Top排名，不乏盛名之下，其实难副的伪精品。庆幸的是，《杀人回忆》对得起网络上如出一... (展开)
1726 424 216回应 收起
悠客 2007-09-30 17:40:06

## 凶手好比那只蚱蜢

电影开场的配乐很赞，几声钢琴键的敲击，舒缓简洁，却营造出怀旧的时空感。画面亮起，湛蓝的天空簇拥着大朵大朵的白云，大地上一片无边的金黄麦田，好一幅优美的乡村静景。稍顷，远处居中的群山上方依次显现出几个草体字：杀人回忆。—个现实中悬而未决16年的系列奸杀案就在这... (展开)
1452 151 113回应 收起
江浪 2010-08-21 00:26:00

## 后现代主义杰作！

这篇影评可能有剧透

电影中的情节远比我的梗概更错综复杂而精彩刺激。我总觉得它不是一部单纯的娱乐片，而是一部相当严肃的电影，它探讨的不止是一桩震撼了一代韩国人的凶残案件，而是一些更深层次的问题。在电影中我看到一系列深刻的正反对立。 从角色设定来看，胖警官朴某和... (展开)
942 133 102回应 收起
九尾黑猫 2007-11-13 17:32:01

## 《杀人回忆》的隐喻——当历史毁灭真相

一、蒙眼的正义女神 　　在希腊神话的“青铜时代”中，世界不再祥和美好，而是充满谎言、暴力、血腥，人们一步步走向罗网和罪孽。正义女神狄刻手中那衡量正义与邪恶的天平不堪重负，她的同伴“羞耻”和“敬畏”两位女神甚至无法忍受这样的景象，终于抛弃了人类，回到奥利... (展开)
762 153 65回应 收起
瞪瞪小眼 2011-11-07 02:09:04

## 杀人回忆凶手的详细分析和猜想

这篇影评可能有剧透

第一种理解 警察的方向根本都是错的，凶手另有他人，或者多人模仿杀人，但都不是警方关注的，这种说法说的通，这里不多解释了。 第二种理解:凶手是小白脸（朴兴圭），DNA是猥琐男（红裤衩）偶然看到尸体后，进行SY留下的。 第三种理解(个人的猜想） 假设1：首先这是建... (展开)
782 82 152回应 收起
子戈 2019-09-24 07:39:35

## 《杀人回忆》的真凶，不是“人”

01 提起《杀人回忆》，所有人都会称赞它的结尾有多经典。 宋康昊转过头，面带惊恐地看向屏幕外的观众。 仿佛在说：凶手此刻就在我们之中。 这个镜头确实很震撼。 但我想说，与之相比，影片的开场同样精彩。 那是一个艳阳高照的午后，一派平静祥和的乡村景象。 一个少年在稻田里... (展开)
632 3 36回应 收起
茧子 2010-05-18 11:54:38

## 五年之后重看杀人回忆

首先围绕电影，谈谈谁是凶手？ 韩国这起未破的系列杀人案，究竟真相和证据如何、是否有朴兴奎这么个类似的嫌疑人，我们现在不得而知（希望哪位豆友有这方面知识和途径可以获悉），能讨论的仅仅是依靠影片给出的线索。 正因如此，影片在排除了傻子白光昊、手淫者乔秉淳后，嫌疑... (展开)
318 79 63回应 收起
王韦到来 2019-11-11 21:52:08 #《杀人回忆》有哪些值得关注的细节？

## 一场横跨30年的追查，15起谋杀30余起强奸《杀人回忆》全案回忆解析

这篇影评可能有剧透

2019年9月18日，从黄海另一端传来的消息排上了国内热搜。韩国三大悬案之一“华城连环杀人案”有了新的进展。这起案件之所以能够跨越大洋被世界各地广为周知，起因是2003年“杀人回忆”这部电影，影片展示了1986年至1991年间，发生在韩国京畿道华城郡泰安邑一带的连环强奸谋杀案... (展开)
304 3 19回应 收起

> 更多影评 1630篇

添加新讨论

## 讨论区 · · · · · ·

有两处警察在暴打女生…… | 来自Kim | 2 回应 | 2022-11-24 01:25:58
宋康昊的眼力什么水平？他能不能看出凶手 | 来自旷 | 7 回应 | 2022-11-23 01:06:37
奉俊昊可以拍杀人回忆2 | 来自The | 2 回应 | 2022-11-22 00:21:55
韩国有回忆，中国有朱令！ | 来自尘世尘埃 | 3 回应 | 2022-11-22 00:21:03
凶手原型现已找到了 | 来自余情 | 4 回应 | 2022-11-22 00:10:28

> 去这部影片的讨论区（全部570条）

## 关于《杀人回忆》的问题 · · · · · · ( 全部67个 )

- 宋康昊饰演的朴探员最后看着镜头是什么意思？ 23人回答
- 山上的女人为什么没有死？ 16人回答

> 全部67个问题

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 【意外结局】 (影志)
- 【豆瓣五星电影集中营】(1/3) (影志)
- 【真实犯罪】—— 真人真事改编案件（世界版1） (狷介有乌青)
- 木卫清单｜你不应该错过的100部韩国电影 (木卫二)

## 谁在看这部电影 · · · · · ·

- 朱晓凤
  3分钟前 看过
- Palpitate.
  4分钟前 想看
- 沉默是最好的
  5分钟前 看过

886257人看过 / 309101人想看

订阅杀人回忆的评论:
feed: rss 2.0